@@ -8,6 +8,8 @@ class Menu(BaseModel):
     title: Optional[bool]
     url: Optional[str]
     icon: Optional[str]
+    # children meun
+    children: Optional[List['Menu']] = []
     # include fields
     include: Optional[Tuple[str]]
     # exclude fields
@@ -31,6 +33,9 @@ class Menu(BaseModel):
     }]
 
 
+Menu.update_forward_refs()
+
+
 class Site(BaseModel):
     name: str
     logo: HttpUrl
